Feature<T extends GeometryObject> class

Inheritance
Available extensions

Constructors

Feature({BBox? bbox, dynamic id, Map<String, dynamic>? properties = const {}, T? geometry, Map<String, dynamic> fields = const {}})
Feature.fromJson(Map<String, dynamic> json)
factory

Properties

bbox BBox?
getter/setter pairinherited
fields Map<String, dynamic>
getter/setter pair
geometry ↔ T?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id ↔ dynamic
getter/setter pair
properties Map<String, dynamic>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type GeoJSONObjectType
finalinherited

Methods

clone() Feature<T>
override
coordAll() List<Position?>

Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension

coordEach(CoordEachCallback callback) → void

Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension

coordReduce<T>(CoordReduceCallback<T> callback, T? initialValue, [bool excludeWrapCoord = false]) → T?

Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension

featureEach(FeatureEachCallback callback) → void

Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension

featureReduce<T>(FeatureReduceCallback<T> callback, T? initialValue) → T?

Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension

flattenEach(FlattenEachCallback callback) → void

Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension

flattenReduce<T>(FlattenReduceCallback<T> callback, T? initialValue) → T?

Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension

geomEach(GeomEachCallback callback) → void

Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension

geomReduce<T>(GeomReduceCallback<T> callback, T? initialValue) → T?

Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
propEach(PropEachCallback callback) → void

Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension

propReduce<T>(PropReduceCallback<T> callback, T? initialValue) → T?

Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension

segmentEach(SegmentEachCallback callback) → void

Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension

segmentReduce<T>(SegmentReduceCallback<T> callback, T? initialValue, {bool combineNestedGeometries = true}) → T?

Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension

serialize(Map<String, dynamic> map) Map<String, dynamic>
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override
operator [](String key) → dynamic