DistanceGeometry enum
Whether to calculate the distance based on geodesic (spheroid) or planar (flat) method.
Values
- planar → const DistanceGeometry
-
Calculations will be made on a 2D plane, NOT taking into account the earth curvature.
- geodesic → const DistanceGeometry
-
Calculate the distance with geodesic (spheroid) equations. It will take into account the earth as a sphere.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DistanceGeometry> - A constant List of the values in this enum, in order of their declaration.