copyWithPreservingOtherMembers method
CopyWith method that preserves other members This is used to create a new GeoJSONObject with some properties modified while preserving all other members
Implementation
GeoJSONObject copyWithPreservingOtherMembers() {
return clonePreservingOtherMembers();
}