Point class
Point, as specified here https://tools.ietf.org/html/rfc7946#section-3.1.2
- Inheritance
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
Properties
- bbox ↔ BBox?
-
getter/setter pairinherited
- coordinates ↔ Position
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setteroverride
-
otherMembers
→ Map<
String, dynamic> -
Available on GeoJSONObject, provided by the GeoJSONObjectOtherMembersExtension extension
Get other members for this GeoJSON objectno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → GeoJSONObjectType
-
finalinherited
Methods
-
clone(
) → Point -
override
-
clonePreservingOtherMembers<
T extends GeoJSONObject> () → T -
Available on GeoJSONObject, provided by the GeoJSONObjectOtherMembersExtension extension
Clone with other members preserved -
coordAll(
) → List< Position?> -
Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension
-
coordEach(
CoordEachCallback callback) → void -
Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension
-
coordReduce<
T> (CoordReduceCallback< T> callback, T? initialValue, [bool excludeWrapCoord = false]) → T? -
Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension
-
copyWithPreservingOtherMembers(
) → GeoJSONObject -
Available on GeoJSONObject, provided by the GeoJSONObjectOtherMembersExtension extension
CopyWith method that preserves other members This is used to create a new GeoJSONObject with some properties modified while preserving all other members -
copyWithPreservingOtherMembers(
{BBox? bbox}) → GeometryObject -
Available on GeometryObject, provided by the GeometryObjectOtherMembersExtension extension
Create a new GeometryObject with modified properties while preserving other members -
featureEach(
FeatureEachCallback callback) → void -
Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension
-
featureReduce<
T> (FeatureReduceCallback< T> callback, T? initialValue) → T? -
Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension
-
flattenEach(
FlattenEachCallback callback) → void -
Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension
-
flattenReduce<
T> (FlattenReduceCallback< T> callback, T? initialValue) → T? -
Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension
-
geomEach(
GeomEachCallback callback) → void -
Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension
-
geomReduce<
T> (GeomReduceCallback< T> callback, T? initialValue) → T? -
Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension
-
mergeOtherMembers(
Map< String, dynamic> newMembers) → void -
Available on GeoJSONObject, provided by the GeoJSONObjectOtherMembersExtension extension
Merge additional other members with existing ones -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
propEach(
PropEachCallback callback) → void -
Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension
-
propReduce<
T> (PropReduceCallback< T> callback, T? initialValue) → T? -
Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension
-
segmentEach(
SegmentEachCallback callback) → void -
Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension
-
segmentReduce<
T> (SegmentReduceCallback< T> callback, T? initialValue, {bool combineNestedGeometries = true}) → T? -
Available on GeoJSONObject, provided by the GeoJSONObjectMetaExtension extension
-
serialize(
Map< String, dynamic> map) → Map<String, dynamic> -
inherited
-
setOtherMembers(
Map< String, dynamic> members) → void -
Available on GeoJSONObject, provided by the GeoJSONObjectOtherMembersExtension extension
Set other members for this GeoJSON object -
toJson(
) → Map< String, dynamic> -
override
-
toJsonWithOtherMembers(
) → Map< String, dynamic> -
Available on GeoJSONObject, provided by the GeoJSONObjectOtherMembersExtension extension
Convert to JSON with other members included This is the compliant serialization method that includes other members as per RFC 7946 specification. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override